<?php
/*
 * chouchenn wonderslip
 * Copyright (c) 2004 olo <wonderslip at olivierl dot org>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */

/**************************************************
 * Demo
 **************************************************/

print("<?xml version='1.0' encoding='iso-8859-15'?>\n"); ?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.1//EN" "http://www.w3.org/TR/xhtml11/DTD/xhtml11.dtd">
<html xmlns="http://www.w3.org/1999/xhtml" xml:lang="fr">
<head>
	<title>wonderslip</title>
	<style type="text/css" media="screen" title="basic style">
#bouchot ul, li {
	clear: both;
}
#bouchot > ul > li {
	list-style: none;
}
.horloge {
	padding-left: 0.2em;
}
.login {
	color: gray;
	background-color: transparent;
}
.strike {
	text-decoration: line-through;
}
.underline {
	text-decoration: underline;
}
img {
	border: 0;
}
:target {
	background-color: #ececec;
}
	</style>
	<script type="text/javascript">
function highlight(clocks) {
	styleClock = document.createElement('style');
	styleClock.setAttribute('id','styleClock');
	styleClock.setAttribute('media','screen');
	style = "";
	for (i = 0; i < arguments.length; i++) {
		style += '.' + arguments[i] + ' { background-color: #ececec; } ';
	}
	document.getElementsByTagName('head')[0].appendChild(styleClock);
	document.getElementById('styleClock').appendChild(document.createTextNode(style));
}

function unhighlight() {
	styleClock = document.getElementById('styleClock');	
	styleClock.parentNode.removeChild(styleClock);
}
	</script>
</head>
<body>

<?php

define('WS_BasePath', 'lib/');
include(WS_BasePath.'ws.php');

$clockTracker = new ClockTracker();

?>

	<div id="bouchot">
	<ul>
<?php
list($classes, $_classes, $ids) = $clockTracker->getClassesAndIds(14, 51, 43);
print("<li class=\"$classes\">\n");
foreach ($ids as $id) print("<span id=\"$id\" />");
print("\n");
?>
<!--
		<li class="clock1451431 clock145143 clock14511 clock1451">
			<span id="clock1451431" /><span id="clock145143" /><span id="clock14511" /><span id="clock1451" />
-->
			<span class="horloge" title="did" onmouseover="highlight(<?php print($_classes); ?>)" onmouseout="unhighlight()">
				14:51:43
			</span>
<!--
			<span class="horloge" title="did" onmouseover="highlight('_clock1451431', '_clock145143', '_clock14511', '_clock1451')" onmouseout="unhighlight()">
				14:51:43
			</span>
-->
			<span class="login">
				didbaba&gt;
			</span> 
		replop
<?php
print("</li>\n");

list($classes, $_classes, $ids) = $clockTracker->getClassesAndIds(14, 51, 43);
print("<li class=\"$classes\">\n");
foreach ($ids as $id) print("<span id=\"$id\" />");
print("\n");
?>
<!--
		<li class="clock1451432 clock145143 clock14512 clock1451">
			<span id="clock1451432" /><span id="clock14512" />
-->
			<span class="horloge" title="Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.6) Gecko/20040" onmouseover="highlight(<?php print($_classes); ?>)" onmouseout="unhighlight()">
				14:51:43
			</span>
<!--
			<span class="horloge" title="Mozilla/5.0 (X11; U; Linux i686; en-US; rv:1.6) Gecko/20040" onmouseover="highlight('_clock1451432', '_clock145143', '_clock14512', '_clock1451')" onmouseout="unhighlight()">
				14:51:43
			</span>
-->
		 <img src="http://jr@forum.hardware.fr/images/perso/banguy.gif" alt="[:banguy]" title="[:banguy]"/>
<?php
print("</li>\n");

list($classes, $_classes, $ids) = $clockTracker->getClassesAndIds(18, 45, 38);
print("<li class=\"$classes\">\n");
foreach ($ids as $id) print("<span id=\"$id\" />");
print("\n");
?>
<!--
		<li class="clock1845381 clock184538 clock18451 clock1845">
			<span id="clock1845381" /><span id="clock184538" /><span id="clock18451" /><span id="clock1845" />
-->
			<span class="horloge" title="wmCoinCoin/2.4.6b - olo - cps:48.1365:-1.6652" onmouseover="highlight(<?php print($_classes); ?>)" onmouseout="unhighlight()">
				18:45:38
			</span>
<!--
			<span class="horloge" title="wmCoinCoin/2.4.6b - olo - cps:48.1365:-1.6652" onmouseover="highlight('_clock1845381', '_clock184538', '_clock18451', '_clock1845')" onmouseout="unhighlight()">
				18:45:38
			</span>
-->
			<span class="login">
				olo&gt;
			</span> 
		 <a class="_clock145143 clock145143 clock1451" onmouseover="highlight('clock145143')" onmouseout="unhighlight()" href="#clock145143">14:51:43</a> <img src="http://jr@forum.hardware.fr/images/perso/hello.gif" alt="[:hello]" title="[:hello]"/>
		 <a class="_clock1451432 clock1451432 clock145143 clock14512 clock1451" onmouseover="highlight('clock1451432')" onmouseout="unhighlight()" href="#clock1451432">14:51:43</a> <img src="http://jr@forum.hardware.fr/images/perso/hello.gif" alt="[:hello]" title="[:hello]"/>
		 <a class="_clock1451431 clock1451431 clock145143 clock14511 clock1451" onmouseover="highlight('clock1451431')" onmouseout="unhighlight()" href="#clock1451431">14:51:43:1</a> <img src="http://jr@forum.hardware.fr/images/perso/hello.gif" alt="[:hello]" title="[:hello]"/>
<?php
print("</li>\n");
?>
	</ul>
	</div>

<?php

WS_setWiki(
	'http://wiki.woof.lu/?',
	array(
		'woof' => 'http://wiki.woof.lu/?',
		'llfr' => 'http://wiki.logicielslibres.info/index.php/'
	)
);
WS_setSmileyWiki('http://wiki.woof.lu/?');
//WS_setSmileyUrl('');
WS_setBoards(
	array(
		'woof' => 'http://woof.lu/board/',
		'linuxfr' => 'http://linuxfr.org/board/',
		'dlfp' => 'http://linuxfr.org/board/',
		'daique' => 'http://daique.dyndns.org/board/'
	),
	array('me', 'alias')
);
WS_addAllowedTag('m');
WS_addTagReplacement('m', '====> <b>Moment ', '</b> <====');
//WS_addTagReplacement('u', '<span style="text-decoration: underline">', '</span>', WS_OUT_HTML);
//WS_addTagReplacement('s', '<span style="text-decoration: line-through">', '</span>', WS_OUT_HTML);
WS_setAllowedProtocols(array('http://', 'https://', 'ftp://', 'mailto:', 'ipot://', 'ed2k://', 'rsync://'));

function bugNumber(&$context, &$properties)
{
	$properties['title'] = "'bug $context->currentString'";
	$properties['url'] = 'http://daique.dyndns.org/phpbt/bug.php?op=show&amp;'
		.'bugid='.substr($context->currentString, 1);
}
WS_addState(
	'bug0',
	state(
		endOfData('text'),
		other('text'),
		array(
			char('\d', 'bug1')
		)
	)
);
WS_addState(
	'bug1',
	state(
		endOfData('bug', NOCONS, array('bugNumber')),
		other('bug', NOCONS, array('bugNumber')),
		array(
			char('\d', 'bug1')
		)
	)
);
WS_addState(
	'bug',
	term($WS_T_Url)
);
WS_addTransition('init', char('#', 'bug0'));

$data = isset($HTTP_POST_VARS["data"])
	? (get_magic_quotes_gpc() ? $HTTP_POST_VARS["data"] : stripslashes($HTTP_POST_VARS["data"]))
	: "#42 2:34:32abc<u> \$plop <u>underline</u> <s>strike</s> <tt>chuuut</tt> <m>talo</m>\n <u>test https://plop</u> [plop] [:totoz] </b > <i>plop <b>daique<</b> a marche :p</i> [:bou_le_loup   tt]\n\t<b>toto<i>titi</b>tata</i> 2:3 14h51m 18h45:38@me 02h03: \n 020304-2 1234@plop-1 02:03:04:4@woof-1 12:42:56@-1 02:63:04:4-1 02:03: 02:03:04:4@0plip42 02:03:04:4@\n[plop\nplop] [plop@woof][plop@woof0][plop@woof@wiki.logicielslibres.info/index.php/][][@woof][@][@@llfr]ed2k://|file|Et%20La%20Tendresse%20Bordel.avi|729636864|FE758DF2C262A5FEC03AE93E46D2CE81|/";
print("<hr />\n<h4>raw data</h4>\n<pre xml:space=\"preserve\">".htmlspecialchars($data)."</pre>\n");

$tokens = WS_getTokens($data);

print("<hr />\n<h4>length</h4>\n<p>");
$checkLength = WS_checkLength($tokens, 256, 42);
if ($checkLength == WS_LENGTH_OK) {
	print "0 - ok";
} else if ($checkLength == WS_LENGTH_NOK_POST) {
	print "1 - too long post";
} else /*if ($checkLength == WS_LENGTH_NOK_WORD)*/ {
	print "2 - too long word";
}
print("</p>\n");

print("<hr />\n<h4>xhtml code</h4>\n<p>");
print(WS_getOutput($tokens, WS_OUT_HTML));
print("</p>");

print("<hr />\n<h4>xml backend code (encoded)</h4>\n<p>");
print(htmlspecialchars(WS_getOutput($tokens, WS_OUT_XML)));
print("</p>");

print("<hr />\n<h4>wml code (encoded)</h4>\n<p>");
print(htmlspecialchars(preg_replace(',\$,', '$$', WS_getOutput($tokens, WS_OUT_WML))));
print("</p>");
/*
print("<hr />\n<h4>serialized tokens (encoded)</h4>\n<p>");
print(htmlspecialchars(WS_serialize($tokens)));
print("</p>");
*/
print("<hr />\n<h4>serialized merged tokens (encoded)</h4>\n<p>");
print(htmlspecialchars(WS_serialize(WS_mergeTextTokens($tokens))));
print("</p>");

print("<hr />\n<h4>unserialized merged tokens - xhtml code</h4>\n<p>");
print(WS_getOutput(WS_unserialize(WS_serialize(WS_mergeTextTokens($tokens))), WS_OUT_HTML));
print("</p>");

?>
<hr />
<h4>test it!</h4>
<form method="post" action="./taiste.php">
<p>
<input id="data" name="data" type="text" maxlength="512" size="100" value="<?php print(htmlspecialchars($data)); ?>" />
</p>
</form>
<hr />
<p>
	<a href="http://validator.w3.org/check/referer"><img
		src="http://www.w3.org/Icons/valid-xhtml11"
		alt="Valid XHTML 1.1!" height="31" width="88" /></a>

	<a href="http://plop.olivierl.org/"><img src="http://hules.free.fr/wmcoincoin/bumperptramo.png" alt="FREE PIERRE TRAMO !" title="FREE PIERRE TRAMO !"/></a>
</p>
</body>
</html>